@@ -1,10 +1,10 @@
 use std::str::FromStr;
 
 use proc_macro2::{Span, TokenStream};
-use quote::ToTokens;
-use syn::{self, Data, DeriveInput, Field, Fields, Ident, Meta, NestedMeta};
+use quote::{quote, ToTokens};
+use syn::{self, parse_quote, Data, DeriveInput, Field, Fields, Ident, Meta, NestedMeta};
 
-use util::*;
+use crate::util::*;
 
 #[derive(Default, Debug)]
 struct ObjAttrs {
@@ -149,8 +149,8 @@ pub fn impl_input_object(ast: &syn::DeriveInput, is_internal: bool) -> TokenStre
     let generics = &ast.generics;
 
     let meta_description = match attrs.description {
-        Some(descr) => quote!{ let meta = meta.description(#descr); },
-        None => quote!{ let meta = meta; },
+        Some(descr) => quote! { let meta = meta.description(#descr); },
+        None => quote! { let meta = meta; },
     };
 
     let mut meta_fields = TokenStream::new();
@@ -170,12 +170,12 @@ pub fn impl_input_object(ast: &syn::DeriveInput, is_internal: bool) -> TokenStre
             }
             None => {
                 // Note: auto camel casing when no custom name specified.
-                ::util::to_camel_case(&field_ident.to_string())
+                crate::util::to_camel_case(&field_ident.to_string())
             }
         };
         let field_description = match field_attrs.description {
-            Some(s) => quote!{ let field = field.description(#s); },
-            None => quote!{},
+            Some(s) => quote! { let field = field.description(#s); },
+            None => quote! {},
         };
 
         let default = {
@@ -183,7 +183,7 @@ pub fn impl_input_object(ast: &syn::DeriveInput, is_internal: bool) -> TokenStre
                 Some(quote! { Default::default() })
             } else {
                 match field_attrs.default_expr {
-                    Some(ref def) => match ::proc_macro::TokenStream::from_str(def) {
+                    Some(ref def) => match proc_macro::TokenStream::from_str(def) {
                         Ok(t) => match syn::parse::<syn::Expr>(t) {
                             Ok(e) => {
                                 let mut tokens = TokenStream::new();
@@ -205,17 +205,17 @@ pub fn impl_input_object(ast: &syn::DeriveInput, is_internal: bool) -> TokenStre
 
         let create_meta_field = match default {
             Some(ref def) => {
-                quote!{
+                quote! {
                     let field = registry.arg_with_default::<#field_ty>( #name, &#def, &());
                 }
             }
             None => {
-                quote!{
+                quote! {
                     let field = registry.arg::<#field_ty>(#name, &());
                 }
             }
         };
-        meta_fields.extend(quote!{
+        meta_fields.extend(quote! {
             {
                 #create_meta_field
                 #field_description
@@ -227,11 +227,11 @@ pub fn impl_input_object(ast: &syn::DeriveInput, is_internal: bool) -> TokenStre
 
         let from_input_default = match default {
             Some(ref def) => {
-                quote!{
+                quote! {
                     Some(&&#juniper_path::InputValue::Null) | None if true => #def,
                 }
             }
-            None => quote!{},
+            None => quote! {},
         };
 
         from_inputs.extend(quote!{
@@ -249,7 +249,7 @@ pub fn impl_input_object(ast: &syn::DeriveInput, is_internal: bool) -> TokenStre
         });
 
         // Build to_input clause.
-        to_inputs.extend(quote!{
+        to_inputs.extend(quote! {
             (#name, self.#field_ident.to_input_value()),
         });
     }
@@ -332,5 +332,5 @@ pub fn impl_input_object(ast: &syn::DeriveInput, is_internal: bool) -> TokenStre
         }
     };
 
-   body
+    body
 }
